@@ -1,7 +1,7 @@
 from django.contrib.admin.views.decorators import staff_member_required
 from django.urls import path
 
-from .views import ImageUploadView
+from .views import ImageUploadView, LinkToolView
 
 urlpatterns = [
     path(
@@ -9,4 +9,9 @@ urlpatterns = [
         staff_member_required(ImageUploadView.as_view()),
         name='editorjs_image_upload',
     ),
+    path(
+        'linktool/',
+        staff_member_required(LinkToolView.as_view()),
+        name='editorjs_linktool',
+    ),
 ]
